@@ -172,6 +172,11 @@ class ReadTopic(BaseTopic):
     queue_len : `int` (optional)
         The maximum number of items that can be read and not dealt with
         by a callback function or `next` before older data will be dropped.
+    filter_ackcmd : `bool`, optional
+        Filter out cmdack topics so we only see responses to commands
+        that we sent? This is normally what you want, but it is not wanted
+        for SAL/Kafka producers.
+        Ignored if ``name`` != "ackcmd".
 
     Raises
     ------
@@ -218,7 +223,16 @@ class ReadTopic(BaseTopic):
     its own data.
     """
 
-    def __init__(self, *, salinfo, name, sal_prefix, max_history, queue_len=100):
+    def __init__(
+        self,
+        *,
+        salinfo,
+        name,
+        sal_prefix,
+        max_history,
+        queue_len=100,
+        filter_ackcmd=True,
+    ):
         super().__init__(salinfo=salinfo, name=name, sal_prefix=sal_prefix)
         self.isopen = True
         self._allow_multiple_callbacks = False
@@ -252,14 +266,16 @@ class ReadTopic(BaseTopic):
             else salinfo.domain.reader_qos
         )
         self._reader = salinfo.subscriber.create_datareader(self._topic, qos)
+        # TODO DM-26411: replace ANY_INSTANCE_STATE with ALIVE_INSTANCE_STATE
+        # once the OpenSplice issue 00020647 is fixed.
         read_mask = [
             dds.DDSStateKind.NOT_READ_SAMPLE_STATE,
-            dds.DDSStateKind.ALIVE_INSTANCE_STATE,
+            dds.DDSStateKind.ANY_INSTANCE_STATE,
         ]
         queries = []
         if salinfo.index > 0:
             queries.append(f"{salinfo.name}ID = {salinfo.index}")
-        if name == "ackcmd":
+        if name == "ackcmd" and filter_ackcmd:
             queries += [
                 f"origin = {salinfo.domain.origin}",
                 f"host = {salinfo.domain.host}",
@@ -505,14 +521,18 @@ class ReadTopic(BaseTopic):
         """Implement next.
 
         Unlike `next`, this can be called while using a callback function.
+
+        Raises
+        ------
+        RuntimeError
+            If code is already waiting for the next value.
         """
         self.python_queue_length_checker.check_nitems(len(self._data_queue))
         if self._data_queue:
             return self._data_queue.popleft()
         if self._next_task.done():
             self._next_task = asyncio.Future()
-        await asyncio.wait_for(self._next_task, timeout=timeout)
-        return self._data_queue.popleft()
+        return await asyncio.wait_for(self._next_task, timeout=timeout)
 
     async def _callback_loop(self):
         while True:
@@ -561,8 +581,14 @@ class ReadTopic(BaseTopic):
         for data in data_list:
             self._queue_one_item(data)
         self._current_data = data
-        if not self._next_task.done():
-            self._next_task.set_result(None)
+        if not self._data_queue:
+            self.log.warning(
+                f"{self.name}: queue empty after queuing {len(data_list)} items; "
+                "not setting _next_task done."
+            )
+        elif not self._next_task.done():
+            oldest_value = self._data_queue.popleft()
+            self._next_task.set_result(oldest_value)
 
     def _queue_one_item(self, data):
         """Add a single value to the internal queue.
