@@ -192,7 +192,11 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
         those two domains.
         """
         async with salobj.Domain() as domain1, salobj.Domain() as domain2:
-            self.assertNotEqual(domain1.host, domain2.host)
+            # Both domains are constructed with the same host
+            # (if $LSST_DDS_DOMAIN is defined) and origin (the process ID).
+            # We need one or both to be different for command isolation,
+            # so modify the host of one of the domains.
+            domain2.host = domain1.host + 1
             salinfo1 = salobj.SalInfo(domain=domain1, name="Test", index=1)
             salinfo2 = salobj.SalInfo(domain=domain2, name="Test", index=1)
             cmdreader = salobj.topics.ControllerCommand(salinfo=salinfo1, name="wait")
@@ -202,6 +206,17 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
             cmdwriter1 = salobj.topics.RemoteCommand(salinfo=salinfo1, name="wait")
             random.seed(52)
             cmdwriter2 = salobj.topics.RemoteCommand(salinfo=salinfo2, name="wait")
+
+            # Also make an ackcmd reader that sees all data,
+            # to test the ``filter_ackcmd`` argument.
+            unfiltered_ackcmd_reader = salobj.topics.ReadTopic(
+                salinfo=salinfo1,
+                name="wait",
+                sal_prefix="command_",
+                max_history=0,
+                filter_ackcmd=False,
+            )
+
             await salinfo1.start()
             await salinfo2.start()
 
@@ -212,7 +227,14 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
                 )
                 cmdreader.ack(data=data, ackcmd=ackcmd)
 
+            unfiltered_nread = 0
+
+            def unfiltered_reader_callback(self):
+                nonlocal unfiltered_nread
+                unfiltered_nread += 1
+
             cmdreader.callback = reader_callback
+            unfiltered_ackcmd_reader.callback = unfiltered_reader_callback
             num_commands = 3
             for i in range(num_commands):
                 ack1 = await cmdwriter1.start(timeout=STD_TIMEOUT)
@@ -221,6 +243,10 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
                 self.assertEqual(ack1.host, domain1.host)
                 self.assertEqual(ack2.host, domain2.host)
 
+            # The unfiltered reader should see ackcmd replies
+            # from both command writers.
+            self.assertEqual(unfiltered_nread, num_commands * 2)
+
     async def test_controller_telemetry_put(self):
         """Test ControllerTelemetry.put using data=None and providing data.
         """
@@ -603,6 +629,58 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
             for cmd_data, tel_data in zip(cmd_data_list, tel_data_list):
                 self.csc.assert_scalars_equal(cmd_data, tel_data)
 
+    async def test_multiple_next_readers(self):
+        """Test multiple tasks simultaneously calling ``next``.
+
+        Each reader should get the same data.
+        """
+
+        class Reader:
+            """Read data from a ReadTopic using next
+
+            Parameters
+            ----------
+            read_topic : `topics.ReadTopic`
+                Topic to read.
+            nitems : `int`
+                Number of DDS samples to read.
+            """
+
+            def __init__(self, read_topic, nitems, name):
+                self.read_topic = read_topic
+                self.nitems = nitems
+                self.name = name
+                self.data = []
+                self.read_loop_task = asyncio.create_task(self.read_loop())
+
+            async def close(self):
+                self.read_loop_task.cancel()
+
+            async def read_loop(self):
+                while len(self.data) < self.nitems:
+                    data = await self.read_topic.next(flush=False)
+                    self.data.append(data)
+
+        async with self.make_csc(initial_state=salobj.State.ENABLED):
+            nreaders = 3
+            nitems = 5
+            data = list(range(nitems))
+            readers = [
+                Reader(read_topic=self.remote.tel_scalars, nitems=nitems, name=i)
+                for i in range(nreaders)
+            ]
+            await asyncio.sleep(0.1)  # Let Reader read loops start.
+            for item in data:
+                self.csc.tel_scalars.set_put(int0=item)
+                await asyncio.sleep(0.001)  # Let Readers read.
+            await asyncio.wait_for(
+                asyncio.gather(*[reader.read_loop_task for reader in readers]),
+                timeout=STD_TIMEOUT,
+            )
+            for reader in readers:
+                read_data = [item.int0 for item in reader.data]
+                self.assertEqual(data, read_data)
+
     async def test_callbacks(self):
         evt_data_list = []
 
@@ -933,9 +1011,8 @@ class TopicsTestCase(salobj.BaseCscTestCase, asynctest.TestCase):
         for each call, rather than remembering anything from the previous
         command. This is different than WriteTopic.
         """
-        async with salobj.Domain() as domain1, salobj.Domain() as domain2:
-            self.assertNotEqual(domain1.host, domain2.host)
-            salinfo = salobj.SalInfo(domain=domain1, name="Test", index=1)
+        async with salobj.Domain() as domain:
+            salinfo = salobj.SalInfo(domain=domain, name="Test", index=1)
             cmdreader = salobj.topics.ControllerCommand(
                 salinfo=salinfo, name="setScalars"
             )
